# -*- coding: utf-8 -*-

from setuptools import setup

try:
    requires = open('requirements.txt').readlines()
except FileNotFoundError:
    requeires = ['gensim', 'scikit-learn', 'nltk',
                 'six', 'beautifulsoup4', 'requests',
                 'numpy', 'pandas']

setup(
  name='earthy',
  packages=['earthy'],
  version='0.0.3',
  description='',
  install_requires=requires,
  author='Mere Mortal',
  license='MIT',
  url='https://github.com/alvations/earthy',
  #download_url='https://github.com/alvations/earthy/tarball/0.0.2',
  keywords=['natural language processing', 'computational linguistics'],
  classifiers=[],
)



# -*- coding: utf-8 -*-

from __future__ import absolute_import, print_function, division

from earthy.downloader import Downloader


def download(name, download_dir=None, xml_url=None):
    # Create the Downloader object.
    global _downloader
    _downloader = Downloader(download_dir, xml_url)
    _downloader.download(name)
